@@ -23,7 +23,8 @@ int ps_fplot (struct ps_array *psarray, fringesum *fdatum)
     {
     static struct mk4_fringe fringe4;
     int index, ret;
-    char *fname, *fringename(), fullname[256], localname[256];
+    char *fname, fullname[256], localname[256];
+    extern char* fringename(fringesum *);
     char *argv[2];
     static int argc = 1;
     extern char datadir[];
