@@ -11,6 +11,7 @@
 #include "hops_complex.h"
 #include <fftw3.h>
 #include "mk4_data.h"
+#include "mk4_dfio.h"
 #include "param_struct.h"
 #include "pass_struct.h"
 
@@ -51,7 +52,7 @@ struct type_230 *t230)
     if (fftsize != 4 * nl)
         {
         fftsize = 4 * nl;
-        fftplan = fftw_plan_dft_1d (fftsize, work_array, work_array, FFTW_FORWARD, FFTW_MEASURE);
+        fftplan = fftw_plan_dft_1d (fftsize, (fftw_complex*) work_array, (fftw_complex*) work_array, FFTW_FORWARD, FFTW_MEASURE);
         }
 
     for (lag = 0; lag < nl * 2; lag++)
@@ -73,8 +74,8 @@ struct type_230 *t230)
        {
        j = nl - i;
        if (j < 0) j += 4*nl;
-       t230->xpower[i].real = creal(work_array[j]);
-       t230->xpower[i].imag = cimag(work_array[j]);
+       t230->xpower[i].real = real_comp(work_array[j]);
+       t230->xpower[i].imag = imag_comp(work_array[j]);
        }
 
     return (0);
