@@ -118,7 +118,7 @@ class dstats(FFControlStructureBase):
 class c_block(FFControlStructureBase):
     pass
 
-#now decare the c_block fields
+#declare the c_block fields to be aligned with struct c_block of control.h 
 c_block._fields_ = [
     ('cb_chain', ctypes.POINTER(c_block)),
     ('baseline', ctypes.c_char * 2),
@@ -129,20 +129,19 @@ c_block._fields_ = [
     ('skip', ctypes.c_short),
     ('min_weight', ctypes.c_double),
     ('ref_freq', ctypes.c_double),
-#    ('frequency', ctypes.c_int * MAXFREQ),  #MAXFREQ
     ('accept_sbs', ctypes.c_int*MAXFREQ),
-    ('index', ctypes.c_short * 2 * MAXFREQ), #2*MAXFREQ
+    ('index', ctypes.c_short * 2 * MAXFREQ), # deprecated
     ('pc_mode', istats),
     ('pc_period', istats),
-    ('pc_freq', dstats * MAXFREQ), #MAXFREQ
+    ('pc_freq', dstats * MAXFREQ),
     ('pc_phase_offset', dstats * 2 ),
-    ('pc_phase', (dstats * 2) * MAXFREQ), #MAXFREQ
-    ('pc_tonemask', istats * MAXFREQ), #MAXFREQ
+    ('pc_phase', (dstats * 2) * MAXFREQ),
+    ('pc_tonemask', istats * MAXFREQ),
     ('lsb_offset', dstats),
-    ('x_crc', ctypes.c_short),
-    ('y_crc', ctypes.c_short),
-    ('x_slip_sync', ctypes.c_short),
-    ('y_slip_sync', ctypes.c_short),
+    ('x_crc', ctypes.c_short),  # deprecated
+    ('y_crc', ctypes.c_short),  # deprecated
+    ('x_slip_sync', ctypes.c_short),    # deprecated
+    ('y_slip_sync', ctypes.c_short),    # deprecated
     ('sb_window', ctypes.c_double * 2),
     ('mb_window', ctypes.c_double * 2),
     ('dr_window', ctypes.c_double * 2),
@@ -157,7 +156,7 @@ c_block._fields_ = [
     ('use_samples', ctypes.c_short),
     ('dc_block', ctypes.c_short),
     ('optimize_closure', ctypes.c_short),
-    ('gates', gat_struct * 64), #MAXFREQ
+    ('gates', gat_struct * MAXFREQ),
     ('adhoc_phase', ctypes.c_int),
     ('adhoc_tref', ctypes.c_double),
     ('adhoc_period', ctypes.c_double),
@@ -173,14 +172,15 @@ c_block._fields_ = [
     ('gen_cf_record', ctypes.c_int ),
     ('nnotches', ctypes.c_int ),
     ('notches', (ctypes.c_double * 2) * MAXNOTCH ),
+    ('chan_notches', (ctypes.c_double) * (MAXNOTCH + 1) ),
     ('t_cohere', ctypes.c_double),
     ('ionosphere', dstats ),
-    ('delay_offs', dstats * MAXFREQ), #MAXFREQ
+    ('delay_offs', dstats * MAXFREQ),
     ('delay_offs_pol', (dstats * 2) * MAXFREQ ),
     ('nsamplers', ctypes.c_int),
-    ('psamplers', ctypes.POINTER( ctypes.c_char ) * MAX_SAMP ), #MAX_SAMP
+    ('psamplers', ctypes.POINTER( ctypes.c_char ) * MAX_SAMP ),
     ('sampler_codes', ctypes.c_char * 256 ),
-    ('sampler_delay', (dstats * 2) * MAX_SAMP ), #MAX_SAMP * 2
+    ('sampler_delay', (dstats * 2) * MAX_SAMP ),
     ('est_pc_manual', ctypes.c_int),
     ('interpolator', ctypes.c_int),
     ('mbd_anchor', ctypes.c_int),
@@ -190,14 +190,22 @@ c_block._fields_ = [
     ('weak_channel', ctypes.c_double),
     ('pc_amp_hcode', ctypes.c_double),
     ('fmatch_bw_pct', ctypes.c_double),
-    ('chid', ctypes.c_char * MAXFREQ),
+    ('chid', ctypes.c_char * (MAXFREQ + 1) ),
     ('chid_rf', ctypes.c_double * MAXFREQ),
+    ('clones', (ctypes.c_char * (MAXFREQ//2 + 1) ) * 2 ),
+    ('clone_snr_chk', ctypes.c_int),
+    ('display_chans', (ctypes.c_char * (MAXFREQ+5) ) ),
     ('vbp_correct', ctypes.c_int),
     ('vbp_fit', ctypes.c_int),
     ('vbp_coeffs', dstats * 5),
     ('vbp_file', (ctypes.c_char *256) * 2),
     ('mount_type', (ctypes.c_int) * 2 ),
-    ('mixed_mode_rot', ctypes.c_int)
+    ('mixed_mode_rot', ctypes.c_int),
+    ('noautofringes', ctypes.c_int),
+    ('mod4numbering', ctypes.c_int),
+    ('polfringnames', ctypes.c_int),
+    ('mbdrplopt', (ctypes.c_int) * 3),
+    ('fringeout_dir', (ctypes.c_char * 256))
 ] #end of c_block._fields_
 
 
