@@ -9,7 +9,7 @@ from builtins import range
 from past.utils import old_div
 from builtins import object
 import json
-import os
+import os, sys
 import datetime
 #set up module level logger
 import logging
@@ -46,6 +46,7 @@ class Configuration( report_lib.JsonSerializableObject ):
         self.mode = 'VGOS' #can be VGOS or MIXED_MODE
         self.network_reference_station = '' #station to be used as network phase reference
         self.network_reference_station_pol = 'X' #can be 'X' (vgos) or 'R' (mixed-mode)
+        self.network_reference_station_bline_station = '' # station to use as remote station for reference station cblock reads
         self.frequency_group = 'X' #TODO mixed-mode (S or X)...needs work!
         self.target_stations = '' #list of vgos stations to generate pc_phases for
         self.control_file = '' #initial_control_file
@@ -613,17 +614,24 @@ def get_apriori_pc_phases(ffres2pcp_config):
     if mode == 'VGOS':
         #extract the apriori pc_phases for the reference station (only if we are in vgos mode) from the original control file
         #mixed mode reference station is a legacy station with only one polarization (we do not adjust any pc_phases for it)
-        bl_string = network_reference_station + '?'
+        if ffres2pcp_config.network_reference_station_bline_station=='':
+            bl_string = network_reference_station + '?'
+        else:
+            bl_string = network_reference_station + ffres2pcp_config.network_reference_station_bline_station
         cblock = ffcontrol.get_control_block(control_filename, bl_string, ' ', frequency_group, 0)
         ref_pc_phase_x = dict()
         ref_pc_phase_y = dict()
+        print(channels)
         for ch in channels:
             i = ffcontrol.get_fcode_index(ch)
 
+            #print(bl_string+' apriori pcphase:', ch,cblock.pc_phase[i][0].ref,cblock.pc_phase[i][1].ref)
+            
             #nominally the reference station x-pol shouldn't have any non-zero a priori pc_phases, but this can happen (see VGOS memo #51 for reason why)
             ref_pc_phase_x[ch] = cblock.pc_phase[i][0].ref
             ref_pc_phase_y[ch] = cblock.pc_phase[i][1].ref
 
+            
         ref_pc_x = SingleStationPCPhases(network_reference_station, 'X')
         ref_pc_x.add_pc_phases("a-priori", bl_string, 'X', ref_pc_phase_x)
         refstx = network_reference_station + "_" + "X"
@@ -643,8 +651,14 @@ def get_apriori_pc_phases(ffres2pcp_config):
             rem_pc_phase_y = dict()
             for ch in channels:
                 i = ffcontrol.get_fcode_index(ch)
+
+                #print(bl_string+' apriori pcphase:', ch,cblock.pc_phase[i][0].rem,cblock.pc_phase[i][1].rem)
+
                 rem_pc_phase_x[ch] = cblock.pc_phase[i][0].rem
                 rem_pc_phase_y[ch] = cblock.pc_phase[i][1].rem
+
+            #sys.exit()
+                
             rem_pc_x = SingleStationPCPhases(st, 'X')
             rem_pc_x.add_pc_phases("a-priori", bl_string, 'X', rem_pc_phase_x)
             rem_pc_y = SingleStationPCPhases(st, 'Y')
@@ -653,6 +667,8 @@ def get_apriori_pc_phases(ffres2pcp_config):
             remsty = st + "_" + "Y"
             apriori_pcp_list[remstx] = rem_pc_x
             apriori_pcp_list[remsty] = rem_pc_y
+
+
             
     elif mode == 'MIXED_MODE':
         #for the vgos stations X/Y pol, extract the pc phases from the control file
