@@ -425,7 +425,7 @@ class ProxyCableDelayFitPlotter(object):
                 cbar = plt.colorbar(pad=0.2, orientation='horizontal')
                 cbar.set_label('Minimization function')
                 plt.plot(delay, phase_offset*(old_div(180.0,math.pi)), 'r+', markersize=7)
-                ax3.annotate('   ($t$, $\phi$) = (' + str(round(old_div(delay,pcc_delay_fitting.PICOSECOND),2) ) + ' ps, ' + str(round(phase_offset*(old_div(180.0,math.pi)),0)) + '$^\circ$)', xy=(delay, phase_offset*(old_div(180.0,math.pi))), color='red')
+                ax3.annotate(r'   ($t$, $\phi$) = (' + str(round(old_div(delay,pcc_delay_fitting.PICOSECOND),2) ) + r' ps, ' + str(round(phase_offset*(old_div(180.0,math.pi)),0)) + r'$^\circ$)', xy=(delay, phase_offset*(old_div(180.0,math.pi))), color='red')
                 scale_delay = 1e-9
                 ticks_x3 = ticker.FuncFormatter(lambda a, pos: '{0:g}'.format(old_div(a,scale_delay)))
                 ax3.xaxis.set_major_formatter(ticks_x3)
