@@ -2,8 +2,6 @@
 
 #core imports
 from __future__ import absolute_import
-from future import standard_library
-standard_library.install_aliases()
 from builtins import filter
 from builtins import next
 from builtins import str
@@ -18,7 +16,10 @@ import hopstestb as ht
 import ffcontrol
 
 try:
-    from progress.bar import Bar #non-core import
+    try:
+        from progress.bar import Bar #non-core import
+    except:
+        from progressbar import ProgressBar as Bar #non-core import
 except:
     from .utility import Bar #local import
 
@@ -60,11 +61,13 @@ def load_directory_fringe_files(dir_name, baselines_list, frequency_group=None,
         if fg == frequency_group:
             ff_list3.append(x)
 
-    # print("load dir fringes: after fgroup cuts #:", len(ff_list3))
+    #print("load dir fringes: after fgroup cuts #:", len(ff_list3))
 
     #load fringes into memory
     fringe_objects = []
     for ff_name in ff_list3:
+        #sometimes there can be a segfault here; if so, try deleting the fringe file 
+        #print(ff_name)
         f_obj = ffm.FringeFileHandle()
         f_obj.load(ff_name)
         if f_obj.is_valid:
@@ -415,7 +418,7 @@ def apply_fringe_file_cuts(ff_list, control_file_hash, min_snr=0.0, max_snr=1e30
 
     if valid_quality_code_list == None:
         valid_quality_code_list=[0, 1, 2, 3, 4, 5, 6, 7, 8, 9]
-
+    
     filter_list = []
     filter_list.append( DiscreteQuantityFilter("control_file_hash", [control_file_hash]) ) #filter on control file hash
     filter_list.append( DiscreteQuantityFilter("quality", valid_quality_code_list) )
@@ -697,10 +700,11 @@ def load_and_batch_fourfit(exp_directory, network_reference_station, remote_stat
                                         tec_dict = json.load(handle)
                                         rf_scan_name = os.path.abspath(root).split('/')[-2]
                                         #print(rf_scan_name, tec_dict[rf_scan_name], base[0], base[1])
+                                        
                                         dtec = tec_dict[rf_scan_name][base[0]] - tec_dict[rf_scan_name][base[1]]
                                         #print(rf_scan_name, tec_dict[rf_scan_name][base[0]], tec_dict[rf_scan_name][base[1]], dtec)
-                                        # set dTEC search range: +/-50 TECU around the ionex prediction, or 30% of the (absolute) dTEC value, whichever is larger
-                                        dtec_window = max(50,0.3*abs(dtec))
+                                        # set dTEC search range: +/-100 TECU around the ionex prediction, or 50% of the (absolute) dTEC value, whichever is larger
+                                        dtec_window = max(100,0.5*abs(dtec))
                                         set_cmd = set_commands + ' ion_win '+str(dtec-dtec_window)+' '+str(dtec+dtec_window)
                                         #print(set_cmd)
                                 else:
