@@ -216,7 +216,12 @@ class ComplexReImCovarianceMatrix(object):
     def get_phase_variance(self):
         #geometrically this makes sense,
         #but the paper only gives the results in the small angle case: tan\theta ~ \theta
-        sigma_q = math.sqrt(self.iq_mx[1,1])
+
+        # sometimes self.iq_mx[1,1] is a very small negative number - if so, set to zero
+        if np.abs(self.iq_mx[1,1]) < 1e-10 and self.iq_mx[1,1]<0:
+            sigma_q = 0.0
+        else:
+            sigma_q = math.sqrt(self.iq_mx[1,1])
         mag = abs(self.complex_mean)
         sigma_theta = 0.0
         if abs(mag) > 1e-15:
@@ -560,6 +565,10 @@ class StationScanPhaseCalibrationData(object):
         """read in the station p-cal phasor data for this scan and convert to usable format"""
         #read the station data file
         if os.path.isfile(self.station_data_file):
+
+            if self.verbosity > 2:
+                print(self.station_data_file)
+
             station_data = mk4b.mk4sdata(self.station_data_file)
 
             #construct a channel name and tone lookup-table
@@ -576,51 +585,63 @@ class StationScanPhaseCalibrationData(object):
                     tone_freq_to_index[int( round(current_freq,0) )] = ch
                     channel_name_to_index[channel_name] = ch
 
-            #we are assuming the tone-lookup and channel order do not change from one AP to another
-            num_ap = station_data.n309
+            # check that all the expected channels are present
+            if len(channel_name_to_index.keys()) == len(self.single_channel_phasor_collections.keys()):
 
-            #time since LSB pcal sign flip
-            after2012d124 = True
-            if self.start_time.year < 2012 or (self.start_time.year == 2012 and self.start_time.day < 124):
-                after2012d124 = False
+                #we are assuming the tone-lookup and channel order do not change from one AP to another
+                num_ap = station_data.n309
+
+                #time since LSB pcal sign flip
+                after2012d124 = True
+                if self.start_time.year < 2012 or (self.start_time.year == 2012 and self.start_time.day < 124):
+                    after2012d124 = False
+
+                for channel_name in self.single_channel_phasor_collections.keys():
+                    scpc = self.single_channel_phasor_collections[channel_name]
+                    #extract the channel name, sky_frequency, bandwidth and polarization from the vex
+                    scpc.phasor = np.zeros( (scpc.ntones, num_ap), dtype=complex )
+                    scpc.phasor_integer = np.zeros( (scpc.ntones, num_ap), dtype='2uint32' )
+                
+                    ch = channel_name_to_index[channel_name]
+                    #look up the tone phasors:
+                    for ti in list(range(0, scpc.ntones)):
+                        tone_freq = int( round(scpc.tone_offset_freq_array[ti],0) )
+                        if tone_freq in tone_freq_to_index:
+                            tone_phasor_index = tone_freq_to_index[tone_freq]
+                            scpc.frequency_interval.append( NumericalInterval( scpc.tone_physical_freq_array[ti], 0.0 ) )
+                            scpc.time_interval = [None]*num_ap
+                            for ap in list(range(0,num_ap)):
+                                #assume DIFX correlator (which gives centroid of time interval)
+                                pc_time = old_div(station_data.t309[ap].contents.rot, scpc.bandwidth)
+                                scpc.time_interval[ap] = NumericalInterval(pc_time, station_data.t309[ap].contents.acc_period)
+                                u = station_data.t309[ap].contents.chan[ch].acc[tone_phasor_index][0]
+                                v = station_data.t309[ap].contents.chan[ch].acc[tone_phasor_index][1]
+                                if  u != 0 or v != 0 :
+                                    sample_period = 1.0/scpc.sample_rate
+                                    pcp = self.convert_integer_phasor_to_float(u, v, station_data.t309[ap].contents.acc_period, sample_period)
+                                    if scpc.net_sideband == 'L':
+                                        if after2012d124: #correct for LSB pcal sign flip after 2012y124d
+                                            pcp = pcp.conjugate()
+                                            #pcal_interp.c says LSB needs sign flip and 180-deg offset to match Mk3 convention, done by flipping sign of real part
+                                            #however this gives the wrong sign on LSB generated delays, so don't do this
+                                            #pcp = complex( -1.0*pcp.real, pcp.imag)
+                                    scpc.phasor[ti][ap] = pcp
+                                scpc.phasor_integer[ti][ap] = (u,v)
+                    scpc.compute_time_averaged_phasors()
+                #also extract the information about the azimuth and elevation at the site of interest
+                #the value returned is the (az, el) model evaluated at the beginning of the scan
+                #(i.e. the constant term in the model polynomial)
+                self.azimuth = station_data.model[0].t303[0].contents.azimuth[0]
+                self.elevation = station_data.model[0].t303[0].contents.elevation[0]
+                self.valid = True
+
+            else:
+                # the list of channels in this station data file does not match 
+                if self.verbosity > 2:
+                    print('Missing channels! Station data file '+self.station_data_file+' has '+str(len(channel_name_to_index.keys()))+', we are expecting '+str(len(self.single_channel_phasor_collections.keys())))
+                self.valid = False
+                pcc_logger.warning("Warning: station data file "+self.station_data_file+" has "+str(len(channel_name_to_index.keys()))+ " channels, we are expecting "+str(len(self.single_channel_phasor_collections.keys())) + ". Skipping this file.")
 
-            for channel_name in self.single_channel_phasor_collections.keys():
-                scpc = self.single_channel_phasor_collections[channel_name]
-                #extract the channel name, sky_frequency, bandwidth and polarization from the vex
-                scpc.phasor = np.zeros( (scpc.ntones, num_ap), dtype=complex )
-                scpc.phasor_integer = np.zeros( (scpc.ntones, num_ap), dtype='2uint32' )
-                ch = channel_name_to_index[channel_name]
-                #look up the tone phasors:
-                for ti in list(range(0, scpc.ntones)):
-                    tone_freq = int( round(scpc.tone_offset_freq_array[ti],0) )
-                    if tone_freq in tone_freq_to_index:
-                        tone_phasor_index = tone_freq_to_index[tone_freq]
-                        scpc.frequency_interval.append( NumericalInterval( scpc.tone_physical_freq_array[ti], 0.0 ) )
-                        scpc.time_interval = [None]*num_ap
-                        for ap in list(range(0,num_ap)):
-                            #assume DIFX correlator (which gives centroid of time interval)
-                            pc_time = old_div(station_data.t309[ap].contents.rot, scpc.bandwidth)
-                            scpc.time_interval[ap] = NumericalInterval(pc_time, station_data.t309[ap].contents.acc_period)
-                            u = station_data.t309[ap].contents.chan[ch].acc[tone_phasor_index][0]
-                            v = station_data.t309[ap].contents.chan[ch].acc[tone_phasor_index][1]
-                            if  u != 0 or v != 0 :
-                                sample_period = 1.0/scpc.sample_rate
-                                pcp = self.convert_integer_phasor_to_float(u, v, station_data.t309[ap].contents.acc_period, sample_period)
-                                if scpc.net_sideband == 'L':
-                                    if after2012d124: #correct for LSB pcal sign flip after 2012y124d
-                                        pcp = pcp.conjugate()
-                                        #pcal_interp.c says LSB needs sign flip and 180-deg offset to match Mk3 convention, done by flipping sign of real part
-                                        #however this gives the wrong sign on LSB generated delays, so don't do this
-                                        #pcp = complex( -1.0*pcp.real, pcp.imag)
-                                scpc.phasor[ti][ap] = pcp
-                            scpc.phasor_integer[ti][ap] = (u,v)
-                scpc.compute_time_averaged_phasors()
-            #also extract the information about the azimuth and elevation at the site of interest
-            #the value returned is the (az, el) model evaluated at the beginning of the scan
-            #(i.e. the constant term in the model polynomial)
-            self.azimuth = station_data.model[0].t303[0].contents.azimuth[0]
-            self.elevation = station_data.model[0].t303[0].contents.elevation[0]
-            self.valid = True
         else:
             self.valid = False
             pcc_logger.warning("Warning: failed to locate a station file: " + self.station_data_file)
