@@ -321,14 +321,18 @@ def compute_2d_pareto_front(obj_list, par1, par2, maximize1=True, maximize2=True
 ################################################################################
 def print_table(table, n_digits=9):
     """simple formatted print out of a table"""
-    max_width = 0
+    max_width = 10
     for row in table:
-        for col in row:
+        for ii in range(len(row)):
+            #for col in row:
+            col = row[ii]
             if isinstance(col, float):
                 if n_digits > max_width:
                     max_width = n_digits
             else:
-                if len(str(col)) > max_width:
+                # set the justification width using the leftmost column, which should be labels for each row
+                # this fails for multiple columns with wide headings, but we shouldn't be using the same tool for two kinds of tables
+                if ii==0 and len(str(col)) > max_width:
                     max_width = len(str(col))
     max_width += 2;
     for row in table:
