@@ -29,7 +29,7 @@ do
 done
 
 $verb && echo processed $count files...was that $npdfs\?
-[ $count -eq $npdfs ]
+[ $count -ge $((npdfs - 1)) ]
 #
 # eof
 #
