@@ -3,8 +3,6 @@
 #core imports
 from __future__ import print_function
 from __future__ import division
-from future import standard_library
-standard_library.install_aliases()
 from builtins import str
 from past.utils import old_div
 from builtins import range
