@@ -22,7 +22,7 @@ struct time_account
 
 #endif
 
-extern char *account(char *segment_name);
+extern char *account(const char *segment_name);
 
 /*
  * eof
