@@ -19,9 +19,7 @@
 #include <ctype.h>
 #include "aedit.h"
 
-int
-set_stations(arg1, arg2, remarg)
-char *arg1, *arg2, *remarg;
+int set_stations(char *arg1, char *arg2, char *remarg)
 {
 	extern struct inputs inp;
 	int l, i, j;
