@@ -14,8 +14,10 @@
 #include <time.h>
 #include <math.h>
 #include <string.h>
+#include "msg.h"
 #include "vex.h"
 #include "mk4_data.h"
+#include "mk4_dfio.h"
 #include "param_struct.h"
 #ifdef HAVE_CONFIG_H
 #include "hops_config.h"
@@ -23,14 +25,14 @@
 
 
 int
-fill_200 (/* root, param, t200) */
+fill_200 (
 struct scan_struct *root,
 struct type_param *param,
 struct type_200 *t200)
     {
     extern struct mk4_corel cdata; 
     time_t tm;
-    struct tm *utc_now, *gmtime();
+    struct tm *utc_now, *gmtime(const time_t*);
     int int_reftime, year, day, hour, minute, second;
 
     clear_200 (t200);
