@@ -19,10 +19,12 @@
 /*                                                                      */
 /************************************************************************/
 #include <math.h>
+#include "msg.h"
 #include "mk4_data.h"
 #include "param_struct.h"
 #include "pass_struct.h"
-#include "ff_misc_if.h"
+#include "ffcontrol.h"
+//#include "ff_misc_if.h"
 
 int
 gate_off (struct type_pass* pass, int frq, int ap)
@@ -35,7 +37,9 @@ gate_off (struct type_pass* pass, int frq, int ap)
                                         /* control blk */
                                         /* Do all in milliseconds for integer */
                                         /* comparisons */
-    freq_no = fcode(pass->pass_data[frq].freq_code, pass->control.chid);
+    // freq_no = fcode(pass->pass_data[frq].freq_code, pass->control.chid);
+    // See around line 280 of make_passes().
+    freq_no = pass->pass_data[frq].fcode_index;
     mode = pass->control.switched_mode;
 
     period = (int)(pass->control.switched_period * 1000.0);
