@@ -15,12 +15,14 @@
 #include "control.h"
 #include "pass_struct.h"
 #include "param_struct.h"
+#include "msg.h"
+#include "ffcontrol.h"
 
 
 
-int generate_cblock (ovex, pass)
-struct scan_struct *ovex;
-struct type_pass *pass;
+int generate_cblock (
+struct scan_struct *ovex,
+struct type_pass *pass )
     {
     extern struct type_param param;
     extern struct c_block *cb_head;
