@@ -23,6 +23,7 @@
 #include <string.h>
 #include "msg.h"
 #include "pass_struct.h"
+#include "meta_struct.h"
 #include "ovex.h"
 
 #ifdef P_tmpdir
@@ -45,18 +46,6 @@ int make_postplot (struct scan_struct *root,
     static char ps_file[1024];
     double tickinc;
 
-    extern int generate_graphs (struct scan_struct*,
-                         struct type_pass*,
-                         char*,
-                         char*,
-                         double*);
-
-    extern void generate_text (struct scan_struct*,
-                        struct type_pass*,
-                        char*,
-                        char*,
-                        double);
-
                                         /* Create a temporary file to hold */
                                         /* the postscript output */
     strcpy(ps_file, P_tmpdir "/fourfit_XXXXXX");
