@@ -19,12 +19,16 @@
 #include <sys/stat.h>
 #include <stdlib.h>
 #include <string.h>
+#include <getopt.h>
+#include "msg.h"
 #include "mk4_data.h"
+#include "mk4_util.h"
 #include "fstruct.h"
 #include "control.h"
 #include "refringe.h"
 #include "param_struct.h"
 #include "pass_struct.h"
+#include "ffcontrol.h"
 
 #define FALSE 0
 #define TRUE 1
@@ -37,37 +41,38 @@ char *control_string;
 char afile_name[512];
 int displayopt = FALSE;
 
-parse_cmdline (
+int parse_cmdline (
 int argc,
 char **argv,
 fstruct **files,
 bsgstruct **base_sgrp,
 struct type_param *param)
     {
-    char c, base_freq[21], *bf_string();
+    char c, base_freq[21];
     int i, set, cslen, filenum;
     struct stat file_status;
     extern char *optarg;
-    extern int optind, do_only_new, test_mode, plot_xpower,
-    		   do_accounting;
+    extern int optind, test_mode, do_accounting, do_estimation;
     extern int write_xpower;
     extern int refringe, msglev, ap_per_seg, reftime_offset;
-    int do_parse = FALSE, 
-        bf_override = FALSE, 
+    int do_parse = FALSE,
+        bf_override = FALSE,
         cs_too_big = FALSE;
     char *get_bfstring (char *);
                                         // local prototype
     int parse_polar (char *, short int *);
 
+    extern int refringe_list(char*, fstruct**, bsgstruct**);
+
     strcpy (control_filename, "default");
                                         /* Default polarization */
     param->pol = POL_ALL;
     param->first_plot = 0;
     param->nplot_chans = 0;
                                         /* Interpret command line flags */
-    while((c=getopt(argc,argv,"+ab:c:d:f:m:n:pr:s:tuxP:T:X")) != -1) 
+    while((c=getopt(argc,argv,"+ab:c:d:ef:m:n:pr:s:tuxP:T:X")) != -1)
         {
-        switch(c) 
+        switch(c)
             {
             case 'a':
                 do_accounting = TRUE;
@@ -88,7 +93,13 @@ struct type_param *param)
                 displayopt = TRUE;
                 strncpy (display_name,optarg,sizeof(display_name));
                 break;
-            
+
+            case 'e':
+                test_mode = TRUE;
+                do_accounting = TRUE;
+                do_estimation = TRUE;
+                break;
+
             case 'f':
                 param->first_plot = atoi(optarg);
                 break;
@@ -99,7 +110,8 @@ struct type_param *param)
                     msg ("Invalid -m flag argument '%s'", 2, optarg);
                     msg ("Message level remains at %d", 2, msglev);
                     }
-                 //1/27/17 jpb, updated for include '4' as a special parameter which only prints the name of the generated fringe file
+                 //1/27/17 jpb, updated for include '4' as a special parameter
+                 //which only prints the name of the generated fringe file
                 if (msglev > 4) msglev = 4;
                 if (msglev < -3) msglev = -3;
                 break;
@@ -132,10 +144,6 @@ struct type_param *param)
                 test_mode = TRUE;
                 break;
 
-            case 'u':
-                do_only_new = TRUE;
-                break;
-
             case 'x':
                 displayopt = TRUE;
                 strcpy (display_name, "xwindow");
@@ -161,20 +169,16 @@ struct type_param *param)
 
             case '?':
             default:
-                syntax();
+                syntax("$HeadURL$");
                 return (1);
             }
         }
-                                        /* Check for silly states */
-    if (refringe && do_only_new)
-        {
-        msg ("The -r and -u flags are mutually exclusive.", 2);
-        return (1);
-        }
+
                                         /* Read main user control file */
     if (do_parse)
         {
-        if(parse_control_file (control_filename, &(param->control_file_buff), &(param->set_string_buff) ) != 0)
+        if(parse_control_file (control_filename, &(param->control_file_buff),
+            &(param->set_string_buff),0 ) != 0)
             {
             msg ("Fatal error parsing control file '%s'", 3, control_filename);
             return (1);
@@ -182,12 +186,12 @@ struct type_param *param)
         }
                                         /* Look for "set" argument and get the */
                                         /* control file text which follows it */
-    for (set=optind; set<argc; set++) 
+    for (set=optind; set<argc; set++)
         if (strcasecmp (argv[set], "set") == 0) break;
                                         /* Make space, start with enough for -b option */
     cslen = 65;
     for (i=set+1; i<argc; i++) cslen += strlen (argv[i]) + 1;
-    if ((control_string = malloc (cslen)) == NULL)
+    if ((control_string = (char*) malloc (cslen)) == NULL)
         {
         msg ("Could not allocate memory for -b and/or set override options", 3);
         return (1);
@@ -207,12 +211,13 @@ struct type_param *param)
         }
                                         /* Decode -b option argument and append */
                                         /* corresponding control file syntax */
-    if (bf_override) 
+    if (bf_override)
         strcat (control_string, get_bfstring (base_freq));
                                         /* Parse command line override information */
     if (strlen (control_string) > 3)
         {
-        if(parse_control_file (control_string, &(param->control_file_buff), &(param->set_string_buff)) != 0)
+        if(parse_control_file (control_string,
+            &(param->control_file_buff), &(param->set_string_buff), 1) != 0)
             {
             msg ("Fatal error parsing -b option and/or 'set' parameters", 3);
             msg ("Constructed string was '%s'", 3, control_string);
@@ -233,7 +238,7 @@ struct type_param *param)
                                         /* of baselines/subgroups to each root */
     if (refringe)
         {
-        if (refringe_list (afile_name, files, base_sgrp) != 0) 
+        if (refringe_list (afile_name, files, base_sgrp) != 0)
             {
             msg ("Error figuring out data to refringe", 3);
             return (1);
@@ -244,7 +249,7 @@ struct type_param *param)
     else if (get_filelist (set-optind, argv+optind, 0, files) != 0)
         {
         msg ("Error extracting list of files to process from command line args", 2);
-        syntax();
+        syntax("$HeadURL$");
         return (1);
         }
                                         /* Check to see if any data files */
@@ -252,7 +257,7 @@ struct type_param *param)
     if ((*files)[0].order < 0)
         {
         msg ("No valid root files specified", 2);
-        syntax();
+        syntax("$HeadURL$");
         return (1);
         }
 
@@ -267,7 +272,8 @@ int parse_polar (char *field, short *code)
         rc = 1;
     char buff[12];
     if (strcmp (field, "all") == 0)
-        kode = POL_ALL;                 // we will do all present polarizations, one at a time
+        kode = POL_ALL;                 // we will do all present polarizations,
+                                        // one at a time
     else if (strcmp (field, "I") == 0)
         {
         kode = POL_IXY;                 // form Stokes I for linear polarization data
