@@ -22,6 +22,12 @@
 #include "fplot.h"
 #include "msg.h"
 
+// defined in fourfit/pass_struct.h
+#define POL_LL 0
+#define POL_RR 1
+#define POL_LR 2
+#define POL_RL 3
+
 #ifdef P_tmpdir
 # define P_tmpdir "/tmp"
 #endif /* P_tmpdir */
@@ -33,15 +39,56 @@
 // char progname[6] = "fplot";
 // int msglev = 2;
 
+// FIXME: move to sub/dfio/gen_psname.c (later)
+/* this is a verbatim copy from fourfit/display_fplot.c */
+/* note that offset here is 0 due to cmd line processing */
+
+// 9 extra digits should suffice for an integer fn
+static char *gen_psname(char *dn, int ofs, struct mk4_fringe *fringe, int fn)
+{
+    int mm = strlen(dn)+20, pi;
+    char *nn = (char *)calloc(mm, 1), *pp, *svP, *svB, *svF;
+    msg("Incoming filename is %s", 1, dn + ofs);
+    svP = pp = strstr(dn, "%P");
+    if (pp) {
+        // total polarization kludge -- see fill_208.c
+        switch(pi = fringe->t208->unused1[0]) {
+        case POL_LL: pp[0] = 'L'; pp[1] = 'L'; break;
+        case POL_RR: pp[0] = 'R'; pp[1] = 'R'; break;
+        case POL_LR: pp[0] = 'L'; pp[1] = 'R'; break;
+        case POL_RL: pp[0] = 'R'; pp[1] = 'R'; break;
+        default:     pp[0] = pi;  pp[1] = pi;  break;
+        }
+    }
+    svB = pp = strstr(dn, "%B");
+    if (pp) {
+        pp[0] = fringe->t202->baseline[0];
+        pp[1] = fringe->t202->baseline[1];
+    }
+    svF = pp = strstr(dn, "%F");
+    if (pp) {
+        // NB: both must be the same group, but reducing
+        // to on character is more work than we want here.
+        pp[0] = fringe->t203->channels[0].ref_chan_id[0];
+        pp[1] = fringe->t203->channels[0].rem_chan_id[0];
+    }
+    snprintf(nn, mm, dn + ofs, (fn & 0xFFFFFFFF));
+    if (svP) { svP[0] = '%'; svP[1] = 'P'; }
+    if (svB) { svB[0] = '%'; svB[1] = 'B'; }
+    if (svF) { svF[0] = '%'; svF[1] = 'F'; }
+    msg("Generated Filename is %s (dn is %s)", 1, nn, dn);
+    return(nn);
+}
+
 int
 main (int argc, char* argv[])
     {
     int i, display, ret, mk4, size, quit, prompt, poln;
-    char c, cmd[128], pmt[128], *file_name;
+    char c, cmd[128], pmt[128], *file_name, *psname;
     struct mk4_fringe fringe4;
     fstruct *files;
     FILE *fp;
-    static char ps_file[1024] = "fplot_";
+    static char ps_file[2048] = "fplot_";
                                         /* Initialize.  No fstruct entry */
                                         /* with a NULL filename is valid */
                                         /* no need to clear whole struct */
@@ -55,13 +102,11 @@ main (int argc, char* argv[])
     if (parse_cmdline (argc, argv, &files, &display, &file_name, &poln) != 0)
         {
         msg ("Fatal error interpreting command line", 2);
-        /* syntax("$HeadURL: https://barrettj@vault.haystack.mit.edu/svn/hops/trunk/postproc/fplot/fplot.c $"); */
         exit(1);
         }
     if (files[0].order == -1)
         {
         msg ("No valid type-2 files found/specified", 2);
-        /* syntax("$HeadURL: https://barrettj@vault.haystack.mit.edu/svn/hops/trunk/postproc/fplot/fplot.c $"); */
         exit (1);
         }
                                         /* Loop over all filenames */
@@ -123,7 +168,9 @@ main (int argc, char* argv[])
             }
         else if (display == DISKFILE || display == PSTOPDF)
             {
-            snprintf(ps_file, sizeof(ps_file), file_name, i-1);
+            psname = gen_psname(file_name, 0, &fringe4, i-1);
+            //snprintf(ps_file, sizeof(ps_file), file_name, i-1);
+            memcpy(ps_file, psname, strlen(psname)+1);
             if ((fp = fopen (ps_file, "w")) == NULL)
                 {
                 msg ("Could not open PS file (%s) for output", 2, ps_file);
@@ -133,7 +180,7 @@ main (int argc, char* argv[])
             fwrite (fringe4.t221->pplot, 1, size, fp);
             fclose (fp);
             msg ("Created PS plot %s", 1, ps_file);
-            if (display == PSTOPDF) /* continue */
+            if (display == PSTOPDF) /* continue and use PS2PDF */
                 {
                 snprintf(cmd, sizeof(cmd), "%s %s", PS2PDF, ps_file);
                 if (system(cmd))
@@ -152,4 +199,5 @@ main (int argc, char* argv[])
             }
 
         }
+    exit (0);
     }
