@@ -126,7 +126,7 @@ void accum_segs (struct fxparam *fxp)
                 else 
                     segnum = 0;
 
-                if (segnum < 0 || segnum >= MAXSEG) 
+                if (segnum < 0 || segnum >= fxp->nsegs_allocd) 
                     segnum = 0;
                                         /* Maximum segment number + 1 = no. of segs */
                 if (segnum >= fxp->nsegs) 
