@@ -31,7 +31,8 @@ int main (int argc, char **argv)
     static struct fxparam fxp;
     struct loops loops;
     fstruct *files;
-    double set_reffreq();
+    // double set_reffreq();
+    extern double set_reffreq (struct fxparam *fxp);
 
     set_progname("fringex");
     set_msglev(1);
