@@ -74,7 +74,7 @@ copy_309 (struct type_309 *t309,
 
             for (j=0; j<16; j++)    // loop over tones
                 for (k=0; k<2; k++) // loop over quadratures
-                    cp_int (t309_v0->chan[i].acc[j][k], t309->chan[i].acc[j][k]);
+                    cp_uint (t309_v0->chan[i].acc[j][k], t309->chan[i].acc[j][k]);
             }
 
         return (sizeof (struct type_309_v0));
@@ -98,7 +98,7 @@ copy_309 (struct type_309 *t309,
 
             for (j=0; j<64; j++)    // loop over tones
                 for (k=0; k<2; k++) // loop over quadratures
-                    cp_int (t309_v1->chan[i].acc[j][k], t309->chan[i].acc[j][k]);
+                    cp_uint (t309_v1->chan[i].acc[j][k], t309->chan[i].acc[j][k]);
             }
 
         return (sizeof (struct type_309_v1));
